# -*- coding: utf-8 -*-

REGIONI = {
    'Abruzzo': [
        {'abbr': 'AQ', 'nome': "L'Aquila"},
        {'abbr': 'TE', 'nome': 'Teramo'},
        {'abbr': 'PE', 'nome': 'Pescara'},
        {'abbr': 'CH', 'nome': 'Chieti'}
    ],
    'Basilicata': [
        {'abbr': 'PZ', 'nome': 'Potenza'},
        {'abbr': 'MT', 'nome': 'Matera'}
    ],
    'Calabria': [
        {'abbr': 'CS', 'nome': 'Cosenza'},
        {'abbr': 'CZ', 'nome': 'Catanzaro'},
        {'abbr': 'RC', 'nome': 'Reggio di Calabria'},
        {'abbr': 'KR', 'nome': 'Crotone'},
        {'abbr': 'VV', 'nome': 'Vibo Valentia'}
    ],
    'Campania': [
        {'abbr': 'CE', 'nome': 'Caserta'},
        {'abbr': 'BN', 'nome': 'Benevento'},
        {'abbr': 'NA', 'nome': 'Napoli'},
        {'abbr': 'AV', 'nome': 'Avellino'},
        {'abbr': 'SA', 'nome': 'Salerno'}
    ],
    'Emilia-Romagna': [
        {'abbr': 'PC', 'nome': 'Piacenza'},
        {'abbr': 'PR', 'nome': 'Parma'},
        {'abbr': 'RE', 'nome': "Reggio nell'Emilia"},
        {'abbr': 'MO', 'nome': 'Modena'},
        {'abbr': 'BO', 'nome': 'Bologna'},
        {'abbr': 'FE', 'nome': 'Ferrara'},
        {'abbr': 'RA', 'nome': 'Ravenna'},
        {'abbr': 'FC', 'nome': 'Forlì-Cesena'},
        {'abbr': 'RN', 'nome': 'Rimini'}
    ],
    'Friuli-Venezia Giulia': [
        {'abbr': 'UD', 'nome': 'Udine'},
        {'abbr': 'GO', 'nome': 'Gorizia'},
        {'abbr': 'TS', 'nome': 'Trieste'},
        {'abbr': 'PN', 'nome': 'Pordenone'}
    ],
    'Lazio': [
        {'abbr': 'VT', 'nome': 'Viterbo'},
        {'abbr': 'RI', 'nome': 'Rieti'},
        {'abbr': 'RM', 'nome': 'Roma'},
        {'abbr': 'LT', 'nome': 'Latina'},
        {'abbr': 'FR', 'nome': 'Frosinone'}
    ],
    'Liguria': [
        {'abbr': 'IM', 'nome': 'Imperia'},
        {'abbr': 'SV', 'nome': 'Savona'},
        {'abbr': 'GE', 'nome': 'Genova'},
        {'abbr': 'SP', 'nome': 'La Spezia'}
    ],
    'Lombardia': [
        {'abbr': 'VA', 'nome': 'Varese'},
        {'abbr': 'CO', 'nome': 'Como'},
        {'abbr': 'SO', 'nome': 'Sondrio'},
        {'abbr': 'MI', 'nome': 'Milano'},
        {'abbr': 'BG', 'nome': 'Bergamo'},
        {'abbr': 'BS', 'nome': 'Brescia'},
        {'abbr': 'PV', 'nome': 'Pavia'},
        {'abbr': 'CR', 'nome': 'Cremona'},
        {'abbr': 'MN', 'nome': 'Mantova'},
        {'abbr': 'LC', 'nome': 'Lecco'},
        {'abbr': 'LO', 'nome': 'Lodi'},
        {'abbr': 'MB', 'nome': 'Monza e della Brianza'}
    ],
    'Marche': [
        {'abbr': 'PU', 'nome': 'Pesaro e Urbino'},
        {'abbr': 'AN', 'nome': 'Ancona'},
        {'abbr': 'MC', 'nome': 'Macerata'},
        {'abbr': 'AP', 'nome': 'Ascoli Piceno'},
        {'abbr': 'FM', 'nome': 'Fermo'}
    ],
    'Molise': [
        {'abbr': 'CB', 'nome': 'Campobasso'},
        {'abbr': 'IS', 'nome': 'Isernia'}
    ],
    'Piemonte': [
        {'abbr': 'TO', 'nome': 'Torino'},
        {'abbr': 'VC', 'nome': 'Vercelli'},
        {'abbr': 'NO', 'nome': 'Novara'},
        {'abbr': 'CN', 'nome': 'Cuneo'},
        {'abbr': 'AT', 'nome': 'Asti'},
        {'abbr': 'AL', 'nome': 'Alessandria'},
        {'abbr': 'BI', 'nome': 'Biella'},
        {'abbr': 'VB', 'nome': 'Verbano-Cusio-Ossola'}
    ],
    'Puglia': [
        {'abbr': 'FG', 'nome': 'Foggia'},
        {'abbr': 'BA', 'nome': 'Bari'},
        {'abbr': 'TA', 'nome': 'Taranto'},
        {'abbr': 'BR', 'nome': 'Brindisi'},
        {'abbr': 'LE', 'nome': 'Lecce'},
        {'abbr': 'BT', 'nome': 'Barletta-Andria-Trani'}
    ],
    'Sardegna': [
        {'abbr': 'SS', 'nome': 'Sassari'},
        {'abbr': 'NU', 'nome': 'Nuoro'},
        {'abbr': 'CA', 'nome': 'Cagliari'},
        {'abbr': 'OR', 'nome': 'Oristano'},
        {'abbr': 'OT', 'nome': 'Olbia-Tempio'},
        {'abbr': 'OG', 'nome': 'Ogliastra'},
        {'abbr': 'VS', 'nome': 'Medio Campidano'},
        {'abbr': 'CI', 'nome': 'Carbonia-Iglesias'}
    ],
    'Sicilia': [
        {'abbr': 'TP', 'nome': 'Trapani'},
        {'abbr': 'PA', 'nome': 'Palermo'},
        {'abbr': 'ME', 'nome': 'Messina'},
        {'abbr': 'AG', 'nome': 'Agrigento'},
        {'abbr': 'CL', 'nome': 'Caltanissetta'},
        {'abbr': 'EN', 'nome': 'Enna'},
        {'abbr': 'CT', 'nome': 'Catania'},
        {'abbr': 'RG', 'nome': 'Ragusa'},
        {'abbr': 'SR', 'nome': 'Siracusa'}
    ],
    'Toscana': [
        {'abbr': 'MS', 'nome': 'Massa-Carrara'},
        {'abbr': 'LU', 'nome': 'Lucca'},
        {'abbr': 'PT', 'nome': 'Pistoia'},
        {'abbr': 'FI', 'nome': 'Firenze'},
        {'abbr': 'LI', 'nome': 'Livorno'},
        {'abbr': 'PI', 'nome': 'Pisa'},
        {'abbr': 'AR', 'nome': 'Arezzo'},
        {'abbr': 'SI', 'nome': 'Siena'},
        {'abbr': 'GR', 'nome': 'Grosseto'},
        {'abbr': 'PO', 'nome': 'Prato'}
    ],
    'Trentino-Alto Adige/Südtirol': [
        {'abbr': 'BZ', 'nome': 'Bolzano/Bozen'},
        {'abbr': 'TN', 'nome': 'Trento'}
    ],
    'Umbria': [
        {'abbr': 'PG', 'nome': 'Perugia'},
        {'abbr': 'TR', 'nome': 'Terni'}
    ],
    "Valle d'Aosta/Vallée d'Aoste": [
        {'abbr': 'AO', 'nome': "Valle d'Aosta/Vallée d'Aoste"}
    ],
    'Veneto': [
        {'abbr': 'VR', 'nome': 'Verona'},
        {'abbr': 'VI', 'nome': 'Vicenza'},
        {'abbr': 'BL', 'nome': 'Belluno'},
        {'abbr': 'TV', 'nome': 'Treviso'},
        {'abbr': 'VE', 'nome': 'Venezia'},
        {'abbr': 'PD', 'nome': 'Padova'},
        {'abbr': 'RO', 'nome': 'Rovigo'}
    ]
}
